@@ -13,16 +13,19 @@ from ._settings import settings
 from ._thermal_condition import ThermalCondition
 from .base import functor
 
-from . import base
-from . import functors
-from . import indexer
-from . import equilibrium
-from . import exceptions
-from . import functional
-from . import reaction
-from . import mixture
+from . import (base,
+               utils,
+               properties,
+               indexer,
+               equilibrium,
+               exceptions,
+               functional,
+               reaction,
+               mixture)
+
+speed_up = utils.speed_up
 
 __all__ = ('Chemical', 'Chemicals', 'CompiledChemicals', 'Thermo', 'indexer',
            'Stream', 'MultiStream', 'ThermalCondition', 'mixture',
-           'settings', 'functor', 'functors', 'base', 'equilibrium',
-           'exceptions', 'functional', 'reaction')
+           'settings', 'functor', 'properties', 'base', 'equilibrium',
+           'exceptions', 'functional', 'reaction', 'utils', 'speed_up')
