@@ -187,8 +187,8 @@ class Chemical:
              kappa(phase, T, P) -> W/m/K
              V(phase, T, P) -> m^3/mol
              S(phase, T, P) -> J/mol
-             H(phase, T) -> J/mol
-             Cn(phase, T) -> J/mol/K
+             H(phase, T, P=None) -> J/mol
+             Cn(phase, T, P=None) -> J/mol/K
              Psat(T, P=None) -> Pa
              Hvap(T, P=None) -> J/mol
              sigma(T, P=None) -> N/m
@@ -319,7 +319,7 @@ class Chemical:
     >>> # Set top_priority=True to place model in postion [0]
     >>> @Water.Psat.add_model(Tmin=273.20, Tmax=473.20, top_priority=True)
     ... def User_antoine_model(T):
-    ...     return 10.0**(10.116 -  1687.537 / (T + 42.98))
+    ...     return 10.0**(10.116 -  1687.537 / (T - 42.98))
     >>> Water.Psat.show()
     TDependentModelHandle(T, P=None) -> Psat [Pa]
     [0] User_antoine_model
@@ -1116,7 +1116,7 @@ class Chemical:
                  V(phase, T, P) -> m^3/mol
                  S: None
                  H: None
-                 Cn(phase, T) -> J/mol/K
+                 Cn(phase, T, P=None) -> J/mol/K
                  Psat(T, P=None) -> Pa
                  Hvap(T, P=None) -> J/mol
                  sigma(T, P=None) -> N/m
