@@ -31,7 +31,7 @@ def chemical_data_array(chemicals, attr):
 
 class Chemicals:
     """
-    Create Chemicals object that contains Chemical objects as attributes.
+    Create a Chemicals object that contains Chemical objects as attributes.
 
     Parameters
     ----------
@@ -174,7 +174,7 @@ class Chemicals:
 @read_only(methods=('append', 'extend', '__setitem__'))
 class CompiledChemicals(Chemicals):
     """
-    Create CompiledChemicals object that contains Chemical objects as attributes.
+    Create a CompiledChemicals object that contains Chemical objects as attributes.
 
     Parameters
     ----------
@@ -256,7 +256,7 @@ class CompiledChemicals(Chemicals):
                 'get_lle_indices', 'get_synonyms',
                 'get_vle_indices', 'iarray', 'ikwarray',
                 'index', 'indices', 'kwarray', 'refresh_constants', 
-                'retrieve', 'set_synonym', 'subgroup') + self.IDs
+                'set_synonym', 'subgroup') + self.IDs
     
     def __reduce__(self):
         return CompiledChemicals, (self.tuple,)
