@@ -201,7 +201,7 @@ class Stream:
                      Ethanol  0.192
     
     """
-    __slots__ = ('_ID', '_imol', '_TP', '_thermo', '_streams',
+    __slots__ = ('_ID', '_imol', '_thermal_condition', '_thermo', '_streams',
                  '_bubble_point_cache', '_dew_point_cache',
                  '_vle_cache', '_lle_cache',
                  '_sink', '_source', '_price')
@@ -216,7 +216,7 @@ class Stream:
 
     def __init__(self, ID='', flow=(), phase='l', T=298.15, P=101325., units='kmol/hr',
                  price=0., thermo=None, **chemical_flows):
-        self._TP = ThermalCondition(T, P)
+        self._thermal_condition = ThermalCondition(T, P)
         thermo = self._load_thermo(thermo)
         self._init_indexer(flow, phase, thermo.chemicals, chemical_flows)
         self.price = price 
@@ -475,23 +475,23 @@ class Stream:
         [ThermalCondition] Contains the temperature and pressure conditions 
         of the stream.
         """
-        return self._TP
+        return self._thermal_condition
 
     @property
     def T(self):
         """[float] Temperature in Kelvin."""
-        return self._TP.T
+        return self._thermal_condition.T
     @T.setter
     def T(self, T):
-        self._TP.T = T
+        self._thermal_condition.T = T
     
     @property
     def P(self):
         """[float] Pressure in Pascal."""
-        return self._TP.P
+        return self._thermal_condition.P
     @P.setter
     def P(self, P):
-        self._TP.P = P
+        self._thermal_condition.P = P
     
     @property
     def phase(self):
@@ -542,7 +542,7 @@ class Stream:
     @property
     def ivol(self):
         """[Indexer] Flow rate indexer with data in m3/hr."""
-        return self._imol.by_volume(self._TP)
+        return self._imol.by_volume(self._thermal_condition)
     
     ### Net flow properties ###
     
@@ -572,7 +572,7 @@ class Stream:
     @property
     def F_vol(self):
         """[float] Total volumetric flow rate in m3/hr."""
-        return 1000. * self.mixture.V_at_TP(self.phase, self.mol, self._TP)
+        return 1000. * self.mixture.V(self.phase, self.mol, *self._thermal_condition)
     @F_vol.setter
     def F_vol(self, value):
         F_vol = self.F_vol
@@ -582,15 +582,15 @@ class Stream:
     @property
     def H(self):
         """[float] Enthalpy flow rate in kJ/hr."""
-        return self.mixture.H_at_TP(self.phase, self.mol, self._TP)
+        return self.mixture.H(self.phase, self.mol, *self._thermal_condition)
     @H.setter
     def H(self, H):
-        self.T = self.mixture.solve_T(self.phase, self.mol, H, self.T, self.P)
+        self.T = self.mixture.solve_T(self.phase, self.mol, H, *self._thermal_condition)
 
     @property
     def S(self):
         """[float] Entropy flow rate in kJ/hr."""
-        return self.mixture.S_at_TP(self.phase, self.mol, self._TP)
+        return self.mixture.S(self.phase, self.mol, *self._thermal_condition)
     
     @property
     def Hf(self):
@@ -607,12 +607,12 @@ class Stream:
     @property
     def Hvap(self):
         """[float] Enthalpy of vaporization flow rate in kJ/hr."""
-        return self.mixture.Hvap_at_TP(self.mol, self._TP)
+        return self.mixture.Hvap(self.mol, *self._thermal_condition)
     
     @property
     def C(self):
         """[float] Heat capacity flow rate in kJ/hr."""
-        return self.mixture.Cn_at_TP(self.phase, self.mol, self._TP)
+        return self.mixture.Cn(self.phase, self.mol, self.T)
     
     ### Composition properties ###
     
@@ -646,32 +646,32 @@ class Stream:
     def V(self):
         """[float] Molar volume [m^3/mol]."""
         mol = self.mol
-        return self.mixture.V_at_TP(self.phase, mol / mol.sum(), self._TP)
+        return self.mixture.V(self.phase, mol / mol.sum(), *self._thermal_condition)
     @property
     def kappa(self):
         """[float] Thermal conductivity [W/m/k]."""
         mol = self.mol
-        return self.mixture.kappa_at_TP(self.phase, mol / mol.sum(), self._TP)
+        return self.mixture.kappa(self.phase, mol / mol.sum(), *self._thermal_condition)
     @property
     def Cn(self):
         """[float] Molar heat capacity [J/mol/K]."""
         mol = self.mol
-        return self.mixture.Cn_at_TP(self.phase, mol / mol.sum(), self._TP)
+        return self.mixture.Cn(self.phase, mol / mol.sum(), self.T)
     @property
     def mu(self):
         """[float] Hydrolic viscosity [Pa*s]."""
         mol = self.mol
-        return self.mixture.mu_at_TP(self.phase, mol / mol.sum(), self._TP)
+        return self.mixture.mu(self.phase, mol / mol.sum(), *self._thermal_condition)
     @property
     def sigma(self):
         """[float] Surface tension [N/m]."""
         mol = self.mol
-        return self.mixture.sigma_at_TP(mol / mol.sum(), self._TP)
+        return self.mixture.sigma(mol / mol.sum(), *self._thermal_condition)
     @property
     def epsilon(self):
         """[float] Relative permittivity [-]."""
         mol = self.mol
-        return self.mixture.epsilon_at_TP(mol / mol.sum(), self._TP)
+        return self.mixture.epsilon(mol / mol.sum(), *self._thermal_condition)
     
     @property
     def Cp(self):
@@ -711,7 +711,7 @@ class Stream:
         True
         
         """
-        return self._TP.in_equilibrium(other._TP)
+        return self._thermal_condition.in_equilibrium(other._thermal_condition)
     
     def mix_from(self, others):
         """
@@ -812,7 +812,7 @@ class Stream:
             self._imol._data_cache.clear()
         
         if TP:
-            self._TP = other._TP
+            self._thermal_condition = other._thermal_condition
         if flow:
             self._imol._data = other._imol._data
         if phase:
@@ -835,7 +835,7 @@ class Stream:
         
         """
         self._imol._data_cache.clear()
-        self._TP = self._TP.copy()
+        self._thermal_condition = self._thermal_condition.copy()
         self._imol._data = self._imol._data.copy()
         self._imol._phase = self._imol._phase.copy()
         self._init_cache()
@@ -858,7 +858,7 @@ class Stream:
 
         """
         self._imol.copy_like(other._imol)
-        self._TP.copy_like(other._TP)
+        self._thermal_condition.copy_like(other._thermal_condition)
     
     def copy_thermal_condition(self, other):
         """
@@ -876,7 +876,7 @@ class Stream:
          phase: 'l', T: 300 K, P: 101325 Pa
          flow (kg/hr): Water  2
         """
-        self._TP.copy_like(other._TP)
+        self._thermal_condition.copy_like(other._thermal_condition)
     
     def copy_flow(self, stream, IDs=..., *, remove=False, exclude=False):
         """
@@ -982,7 +982,7 @@ class Stream:
         new._sink = new._source = None
         new._thermo = self._thermo
         new._imol = self._imol.copy()
-        new._TP = self._TP.copy()
+        new._thermal_condition = self._thermal_condition.copy()
         new._init_cache()
         new.price = 0
         new.ID = ID
@@ -1010,7 +1010,7 @@ class Stream:
         new._thermo = self._thermo
         new._imol = imol = self._imol._copy_without_data()
         imol._data = self._imol._data
-        new._TP = self._TP.copy()
+        new._thermal_condition = self._thermal_condition.copy()
         new._init_cache()
         return new
     
@@ -1034,7 +1034,7 @@ class Stream:
         new.price = self.price
         new._thermo = self._thermo
         new._imol = self._imol
-        new._TP = self._TP
+        new._thermal_condition = self._thermal_condition
         new._bubble_point_cache = self._bubble_point_cache
         new._dew_point_cache = self._dew_point_cache
         try: new._vle_cache = self._vle_cache
@@ -1432,12 +1432,12 @@ class Stream:
         self._imol = self._imol.to_material_indexer(phases)
         self._streams = {}
         self._vle_cache = utils.Cache(
-                              eq.VLE, self._imol, self._TP,
+                              eq.VLE, self._imol, self._thermal_condition,
                               thermo=self._thermo,
                               bubble_point_cache=self._bubble_point_cache,
                               dew_point_cache=self._dew_point_cache)
         self._lle_cache = utils.Cache(eq.LLE, self._imol,
-                                      self._TP, self._thermo)
+                                      self._thermal_condition, self._thermo)
     
     ### Representation ###
     
