@@ -62,7 +62,7 @@ class VLE:
                  '_H_hat', # [float] Specific enthalpy [kJ/kg].
                  '_V', # [float] Molar vapor fraction.
                  '_thermo', # [float] Thermo object for estimating mixture properties.
-                 '_TP', # [ThermalCondition] T and P results are stored here.
+                 '_thermal_condition', # [ThermalCondition] T and P results are stored here.
                  '_y', # [1d array] Molar vapor composition in equilibrium.
                  '_dew_point', # [DewPoint] Solves for dew point.
                  '_bubble_point', # [BubblePoint] Solves for bubble point.
@@ -102,7 +102,7 @@ class VLE:
         self._bubble_point_cache = bubble_point_cache or Cache(BubblePoint)
         self._load_thermo(thermo)
         self._imol = imol
-        self._TP = thermal_condition or ThermalCondition(298.15, 101325.)
+        self._thermal_condition = thermal_condition or ThermalCondition(298.15, 101325.)
         self._phase_data = tuple(imol)
         self._liquid_mol = liquid_mol = imol['l']
         self._vapor_mol = imol['g']
@@ -150,7 +150,7 @@ class VLE:
         # Run equilibrium
         if T_spec:
             if P_spec:
-                return self.set_TP(T, P)
+                return self.set_thermal_condition(T, P)
             elif V_spec:
                 return self.set_TV(T, V)
             elif H_spec:
@@ -236,11 +236,11 @@ class VLE:
         return self._imol
     @property
     def thermal_condition(self):
-        return self._TP
+        return self._thermal_condition
 
     ### Single component equilibrium case ###
         
-    def _set_TP_chemical(self, T, P):
+    def _set_thermal_condition_chemical(self, T, P):
         # Either liquid or gas
         if P < self._chemical.Psat(T):
             self._liquid_mol[self._index] = 0
@@ -251,13 +251,13 @@ class VLE:
     
     def _set_TV_chemical(self, T, V):
         # Set vapor fraction
-        self._T = self._TP.T = self._chemical.Psat(T)
+        self._T = self._thermal_condition.T = self._chemical.Psat(T)
         self._vapor_mol[self._index] = self._mol*V
         self._liquid_mol[self._index] = self._mol - self._vapor_mol[self._index]
         
     def _set_PV_chemical(self, P, V):
         # Set vapor fraction
-        self._T = self._TP.T = self._chemical.Tsat(P)
+        self._T = self._thermal_condition.T = self._chemical.Tsat(P)
         self._vapor_mol[self._index] = self._mol*V
         self._liquid_mol[self._index] = self._mol - self._vapor_mol[self._index]
         
@@ -271,21 +271,21 @@ class VLE:
         mixture = thermo.mixture
         
         # Set temperature in equilibrium
-        self._T = self._TP.T = T = self._chemical.Tsat(P)
+        self._T = self._thermal_condition.T = T = self._chemical.Tsat(P)
         
         # Check if super heated vapor
         vapor_mol[index] = mol
         liquid_mol[index] = 0
         H_dew = mixture.xH(phase_data, T, P)
         if H >= H_dew:
-            self._TP.T = mixture.xsolve_T(phase_data, H, T, P)
+            self._thermal_condition.T = mixture.xsolve_T(phase_data, H, T, P)
 
         # Check if subcooled liquid
         vapor_mol[index] = 0
         liquid_mol[index] = mol
         H_bubble = mixture.xH(phase_data, T, P)
         if H <= H_bubble:
-            self._TP.T = mixture.xsolve_T(phase_data, H, T, P)
+            self._thermal_condition.T = mixture.xsolve_T(phase_data, H, T, P)
         
         # Adjust vapor fraction accordingly
         V = (H - H_bubble)/(H_dew - H_bubble)
@@ -301,14 +301,14 @@ class VLE:
         phase_data = self._phase_data
         
         # Set Pressure in equilibrium
-        self._TP.P = P = self._chemical.Psat(T)
+        self._thermal_condition.P = P = self._chemical.Psat(T)
         
         # Check if super heated vapor
         vapor_mol[index] = mol
         liquid_mol[index] = 0
         H_dew = thermo.mixture.xH(phase_data, T, P)
         if H >= H_dew:
-            self._TP.T = thermo.xsolve_T(phase_data, H, T, P)
+            self._thermal_condition.T = thermo.xsolve_T(phase_data, H, T, P)
             return
 
         # Check if subcooled liquid
@@ -316,7 +316,7 @@ class VLE:
         liquid_mol[index] = mol
         H_bubble = thermo.mixture.xH(phase_data, T, P)
         if H <= H_bubble:
-            self._TP.T = thermo.xsolve_T(phase_data, H, T, P)
+            self._thermal_condition.T = thermo.xsolve_T(phase_data, H, T, P)
             return
         
         # Adjust vapor fraction accordingly
@@ -337,33 +337,33 @@ class VLE:
     def set_Tx(self, T, x):
         self._setup()
         assert self._N == 2, 'number of species in equilibrium must be 2 to specify x'
-        self._TP.P, y = self._bubble_point.solve_Py(x, T)
+        self._thermal_condition.P, y = self._bubble_point.solve_Py(x, T)
         self._lever_rule(x, y)
     
     def set_Px(self, P, x):
         self._setup()
         assert self._N == 2, 'number of species in equilibrium must be 2 to specify x'
-        self._TP.T, y = self._bubble_point.solve_Ty(x, P) 
+        self._thermal_condition.T, y = self._bubble_point.solve_Ty(x, P) 
         self._lever_rule(x, y)
         
     def set_Ty(self, T, y):
         self._setup()
         assert self._N == 2, 'number of species in equilibrium must be 2 to specify y'
-        self._TP.P, x = self._dew_point.solve_Px(y, T)
+        self._thermal_condition.P, x = self._dew_point.solve_Px(y, T)
         self._lever_rule(x, y)
     
     def set_Py(self, P, y):
         self._setup()
         assert self._N == 2, 'number of species in equilibrium must be 2 to specify y'
-        self._TP.T, x = self._dew_point.solve_Tx(y, P) 
+        self._thermal_condition.T, x = self._dew_point.solve_Tx(y, P) 
         self._lever_rule(x, y)
         
-    def set_TP(self, T, P):
+    def set_thermal_condition(self, T, P):
         self._setup()
-        TP = self._TP
-        self._T = TP.T = T
-        self._P = TP.P = P
-        if self._N == 1: return self._set_TP_chemical(T, P)
+        thermal_condition = self._thermal_condition
+        self._T = thermal_condition.T = T
+        self._P = thermal_condition.P = P
+        if self._N == 1: return self._set_thermal_condition_chemical(T, P)
         # Setup bounderies
         P_dew, x_dew = self._dew_point.solve_Px(self._z, T)
         P_bubble, y_bubble = self._bubble_point.solve_Py(self._z, T)
@@ -389,23 +389,23 @@ class VLE:
                 v = self._solve_v(T, P)
             self._vapor_mol[self._index] = v
             self._liquid_mol[self._index] = self._mol - v
-            self._H_hat = self.mixture.xH_at_TP(self._phase_data, TP)/self._F_mass
+            self._H_hat = self.mixture.xH(self._phase_data, T, P)/self._F_mass
         
     def set_TV(self, T, V):
         self._setup()
-        TP = self._TP
-        TP.T = self._T = T
+        thermal_condition = self._thermal_condition
+        thermal_condition.T = self._T = T
         if self._N == 1: return self._set_TV_chemical(T, V)
         P_dew, x_dew = self._dew_point.solve_Px(self._z, T)
         P_bubble, y_bubble = self._bubble_point.solve_Py(self._z, T)
         if V == 1:
             self._vapor_mol[self._index] = self._mol
             self._liquid_mol[self._index] = 0
-            TP.P = P_dew
+            thermal_condition.P = P_dew
         elif V == 0:
             self._vapor_mol[self._index] = 0
             self._liquid_mol[self._index] = self._mol
-            TP.P = P_bubble
+            thermal_condition.P = P_bubble
         else:
             self._V = V 
             self._refresh_v(V, y_bubble)
@@ -421,10 +421,10 @@ class VLE:
                                 P_bubble, P_dew, 0, 1,
                                 self._P, V,
                                 self.P_tol, self.V_tol)
-            self._P = TP.P = P
+            self._P = thermal_condition.P = P
             self._vapor_mol[self._index] = self._v
             self._liquid_mol[self._index] = self._mol - self._v
-            self._H_hat = self.mixture.xH_at_TP(self._phase_data, TP)/self._F_mass
+            self._H_hat = self.mixture.xH(self._phase_data, T, P)/self._F_mass
 
     def set_TH(self, T, H):
         self._setup()
@@ -447,7 +447,7 @@ class VLE:
         dH_dew = (H - H_dew)
         if dH_dew >= 0:
             self._T = self.mixture.xsolve_T(phase_data, H, T, P_dew)
-            self._TP.P = P_dew
+            self._thermal_condition.P = P_dew
             return
 
         # Check if subcooled liquid
@@ -457,7 +457,7 @@ class VLE:
         dH_bubble = (H - H_bubble)
         if dH_bubble <= 0:
             self._T = self.mixture.xsolve_T(phase_data, H, T, P_bubble)
-            self._TP.P = P_bubble
+            self._thermal_condition.P = P_bubble
             return
 
         # Guess overall vapor fraction, and vapor flow rates
@@ -479,18 +479,19 @@ class VLE:
                             H_bubble/F_mass, H_dew/F_mass,
                             self._P, self._H_hat,
                             self.P_tol, self.H_hat_tol) 
-        self._P = self._TP.P = P   
-        self._TP.T = T
+        self._P = self._thermal_condition.P = P   
+        self._thermal_condition.T = T
     
     def set_PV(self, P, V):
         self._setup()
-        self._TP.P = self._P = P
+        self._thermal_condition.P = self._P = P
         if self._N == 1: return self._set_PV_chemical(P, V)
         
         # Setup bounderies
         T_dew, x_dew = self._dew_point.solve_Tx(self._z, P)
         T_bubble, y_bubble = self._bubble_point.solve_Ty(self._z, P)
         
+        thermal_condition = self._thermal_condition
         index = self._index
         mol = self._mol
         vapor_mol = self._vapor_mol
@@ -499,11 +500,11 @@ class VLE:
         if V == 1:
             vapor_mol[index] = mol
             liquid_mol[index] = 0
-            self._TP.T = T_dew
+            thermal_condition.T = T_dew
         elif V == 0:
             vapor_mol[index] = 0
             liquid_mol[index] = mol
-            self._TP.T = T_bubble
+            thermal_condition.T = T_bubble
         else:
             self._refresh_v(V, y_bubble)
             self._V = V 
@@ -518,14 +519,14 @@ class VLE:
                                 T_bubble, T_dew, 0, 1,
                                 self._T , V,
                                 self.T_tol, self.V_tol)
-            self._T = self._TP.T = T
+            self._T = thermal_condition.T = T
             vapor_mol[index] = self._v
             liquid_mol[index] = mol - self._v
-            self._H_hat = self.mixture.xH(self._phase_data, self._T, P)/self._F_mass
+            self._H_hat = self.mixture.xH(self._phase_data, T, P)/self._F_mass
     
     def set_PH(self, P, H):
         self._setup()
-        self._TP.P = self._P = P
+        self._thermal_condition.P = self._P = P
         if self._N == 1: return self._set_PH_chemical(P, H)
         
         # Setup bounderies
@@ -543,7 +544,7 @@ class VLE:
         H_dew = self.mixture.xH(self._phase_data, T_dew, P)
         dH_dew = H - H_dew
         if dH_dew >= 0:
-            self._TP.T = self.mixture.xsolve_T(self._phase_data, H, T_dew, P)
+            self._thermal_condition.T = self.mixture.xsolve_T(self._phase_data, H, T_dew, P)
 
         # Check if subcooled liquid
         vapor_mol[index] = 0
@@ -551,7 +552,7 @@ class VLE:
         H_bubble = self.mixture.xH(self._phase_data, T_dew, P)
         dH_bubble = H - H_bubble
         if dH_bubble <= 0:
-            self._TP.T = self.mixture.xsolve_T(self._phase_data, H, T_bubble, P)
+            self._thermal_condition.T = self.mixture.xsolve_T(self._phase_data, H, T_bubble, P)
         
         # Guess T, overall vapor fraction, and vapor flow rates
         self._V = V = self._V or dH_bubble/(H_dew - H_bubble)
@@ -559,7 +560,7 @@ class VLE:
         
         F_mass = self._F_mass
         self._H_hat = H/F_mass
-        self._T = self._TP.T = self.solver(self._H_hat_at_T,
+        self._T = self._thermal_condition.T = self.solver(self._H_hat_at_T,
                                            T_bubble, T_dew, 
                                            H_bubble/F_mass, H_dew/F_mass,
                                            self._T , self._H_hat,
