@@ -47,7 +47,8 @@ Tc_methods = [IUPAC, MATTHEWS, CRC, PSRK, PD, YAWS, SURF]
 
 
 def Tc(CASRN, AvailableMethods=False, Method=None, IgnoreMethods=[SURF]):
-    r'''This function handles the retrieval of a chemical's critical
+    r'''
+    This function handles the retrieval of a chemical's critical
     temperature. Lookup is based on CASRNs. Will automatically select a data
     source to use if no Method is provided; returns None if the data is not
     available.
