@@ -46,6 +46,7 @@ References
 import numpy as np
 from scipy.interpolate import interp1d
 from math import log, exp
+from .. import functional as fn
 from .utils import CASDataReader
 from .._constants import R
 from .virial import BVirial_Pitzer_Curl, BVirial_Abbott, BVirial_Tsonopoulos, BVirial_Tsonopoulos_extended
@@ -407,8 +408,8 @@ def Campbell_Thodos(T, Tb, Tc, Pc, MW, dipole=None, has_hydroxyl=False):
     Tr = T/Tc
     Tbr = Tb/Tc
     s = Tbr * log(Pc)/(1-Tbr)
-    Lambda = Pc**(1/3.)/(MW**0.5*Tc**(5/6.))
-    if not has_hydroxyl:
+    Lambda = Pc**(1./3.)/(MW**0.5*Tc**(5./6.))
+    if not (dipole and has_hydroxyl):
         alpha = 0.3883 - 0.0179*s
     beta = 0.00318*s - 0.0211 + 0.625*Lambda**(1.35)
     if dipole:
@@ -420,7 +421,7 @@ def Campbell_Thodos(T, Tb, Tc, Pc, MW, dipole=None, has_hydroxyl=False):
             alpha -= 130540 * theta**2.41
             beta += 9.74E6 * theta**3.38
     Zra = alpha + beta*(1-Tr)
-    Vs = R*Tc/(Pc*101325)*Zra**(1+(1-Tr)**(2/7.))
+    Vs = R*Tc/(Pc*101325)*Zra**(1+(1-Tr)**(2./7.))
     return Vs
 
 @V.l
@@ -515,14 +516,10 @@ def CRC_Inorganic(T, rho0, k, Tm, MW):
     return (rho0 - k*(T-Tm))*f
 
 @V.l
-def VDI_PPDS(T, Tc, k, Vc, A, B, C, D):
+def VDI_PPDS(T, Tc, rhoc, MW, a, b, c, d):
     tau = 1. - T/Tc
-    return Vc + A*tau**0.35 + B*tau**(2/3.) + C*tau + D*tau**(4/3.)
-
-@VDI_PPDS.wrapper
-def VDI_PPDS(Tc, rhoc, MW, A, B, C, D):
-    k = MW / 1e9
-    return {'Tc':Tc, 'k':k, 'Vc':k*rhoc, 'A':k*A, 'B':k*B, 'C':k*C, 'D':k*D}
+    rho = rhoc + a*tau**0.35 + b*tau**(2/3.) + c*tau + d*tau**(4/3.)
+    return fn.rho_to_V(rho, MW)
    
 @V.l(ref="[11]_", doc="auto-header")
 def Costald_Compressed(T, P, Psat, Tc, Pc, omega, Vs):
@@ -581,16 +578,20 @@ def Costald_Compressed(T, P, Psat, Tc, Pc, omega, Vs):
     B = Pc*(-1 + a*tau**(1/3.) + b*tau**(2/3.) + d*tau + e*tau**(4/3.))
     return Vs(T, P)*(1 - C*log((B + P)/(B + Psat(T))))
 
-@TPDependentHandleBuilder
+@TPDependentHandleBuilder('V.l')
 def VolumeLiquid(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, Psat, eos, dipole, has_hydroxyl):
     Tmin = 50
     Tmax = 1000
     all_ = all
     add_model = handle.add_model
+    if CAS in _VDI_PPDS_2:
+        _, MW, Tc_, rhoc, A, B, C, D = _VDI_PPDS_2[CAS]
+        data = (Tc, rhoc, MW, A, B, C, D)
+        add_model(VDI_PPDS.from_args(data), 0., Tc_)
     if CAS in _CRC_inorg_l:
         _, MW, rho, k, Tm, Tmax = _CRC_inorg_l[CAS]
         data = (MW, rho, k, Tm)
-        add_model(CRC_Inorganic.from_args(data), Tm, Tmax, var='V.l')
+        add_model(CRC_Inorganic.from_args(data), Tm, Tmax)
     if CAS in _Perry_l:
         _, C1, C2, C3, C4, Tmin, Tmax = _Perry_l[CAS]
         data = (C1, C2, C3, C4, True)
@@ -598,8 +599,7 @@ def VolumeLiquid(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, Psat, eos, dipole,
     if CAS in _VDISaturationDict:
         Ts, Vls = VDI_tabular_data(CAS, 'Volume (l)')
         model = InterpolatedTDependentModel(Ts, Vls,
-                                            Tmin=Ts[0], Tmax=Ts[-1],
-                                            var='V.l')
+                                            Tmin=Ts[0], Tmax=Ts[-1])
         add_model(model)
     data = (Tc, Vc, Zc)
     if all_(data):
@@ -622,7 +622,7 @@ def VolumeLiquid(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, Psat, eos, dipole,
             add_model(SNM0.from_args(data), 0, Tc)
     if CAS in _CRC_inorg_l_const:
         Vl = float(_CRC_inorg_l_const.at[CAS, 'Vm'])
-        add_model(Vl, Tmin, Tmax, name="CRC_inorganic_liquid_constant", var='V.l')
+        add_model(Vl, Tmin, Tmax, name="CRC_inorganic_liquid_constant")
     if Tc and Pc and CAS in _COSTALD:
         Zc_ = _COSTALD.at[CAS, 'Z_RA']
         if not np.isnan(Zc_): Zc_ = float(Zc_)
@@ -632,18 +632,14 @@ def VolumeLiquid(handle, CAS, MW, Tb, Tc, Pc, Vc, Zc, omega, Psat, eos, dipole,
     data = (Tc, Vc, omega)
     if all_(data) and CAS in _COSTALD:
         add_model(Costald.from_args(data), 0, Tc)
-    data = (Tc, Pc, omega)
-    if CAS in _VDI_PPDS_2:
-        _, MW, Tc_, rhoc, A, B, C, D = _VDI_PPDS_2[CAS]
-        data = (Tc, rhoc, MW, A, B, C, D)
-        add_model(VDI_PPDS.from_args(data), 0., Tc_)
-    if all_(data):
-        data = (Psat, Tc, Pc, omega, handle.copy())
-        add_model(Costald_Compressed.from_args(data), 50, 500, top_priority=True)
     data = (Tb, Tc, Pc, MW, dipole, has_hydroxyl)
     if all_([i is not None for i in data]):
         top_priority = bool(dipole)
         add_model(Campbell_Thodos.from_args(data), 0, Tc, top_priority=top_priority)
+    data = (Tc, Pc, omega)
+    if all_(data):
+        data = (Psat, Tc, Pc, omega, handle.copy())
+        add_model(Costald_Compressed.from_args(data), 50, 500)
         
 
 # %% Gases
@@ -677,7 +673,7 @@ def CRCVirial(T, P, a1, a2, a3, a4, a5):
     t = 298.15/T - 1.
     return ideal_gas(T, P) + (a1 + a2*t + a3*t**2 + a4*t**3 + a5*t**4)/1e6
 
-@TPDependentHandleBuilder
+@TPDependentHandleBuilder('V.g')
 def VolumeGas(handle, CAS, Tc, Pc, omega, eos):
     add_model = handle.add_model
     # no point in getting Tmin, Tmax
@@ -720,12 +716,12 @@ def Goodman(T, Tt, V_l):
     '''
     return (1.28 - 0.16*(T/Tt))*V_l
 
-@TPDependentHandleBuilder
+@TPDependentHandleBuilder('V.s')
 def VolumeSolid(handle, CAS):
     if CAS in _CRC_inorg_s_const:
         CRC_INORG_S_Vm = float(_CRC_inorg_s_const.at[CAS, 'Vm'])
         handle.add_model(CRC_INORG_S_Vm, 0, 1e6, 0, 1e12)
 
 
-Volume = PhaseTPPropertyBuilder(VolumeSolid, VolumeLiquid, VolumeGas, 'V')
+Volume = PhaseTPPropertyBuilder('V', VolumeSolid, VolumeLiquid, VolumeGas)
 
